@@ -4,12 +4,12 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common qw(:Status);
+use IO::Compress::Base::Common  2.003 qw(:Status);
 
-use Compress::Raw::Zlib qw(Z_OK Z_FINISH MAX_WBITS) ;
+use Compress::Raw::Zlib  2.003 qw(Z_OK Z_FINISH MAX_WBITS) ;
 our ($VERSION);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 
 sub mkCompObject
 {
