@@ -6,16 +6,16 @@ use bytes;
 
 require Exporter ;
 
-use IO::Compress::RawDeflate;
+use IO::Compress::RawDeflate 2.003 ;
 
-use Compress::Raw::Zlib ;
-use IO::Compress::Zlib::Constants;
-use IO::Compress::Base::Common qw(createSelfTiedObject);
+use Compress::Raw::Zlib  2.003 ;
+use IO::Compress::Zlib::Constants 2.003 ;
+use IO::Compress::Base::Common  2.003 qw(createSelfTiedObject);
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $DeflateError);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $DeflateError = '';
 
 @ISA    = qw(Exporter IO::Compress::RawDeflate);
@@ -992,7 +992,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
