@@ -4,21 +4,21 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common qw(:Status createSelfTiedObject);
-use IO::Compress::RawDeflate;
-use IO::Compress::Adapter::Deflate;
-use IO::Compress::Adapter::Identity;
-use IO::Compress::Zlib::Extra;
-use IO::Compress::Zip::Constants;
+use IO::Compress::Base::Common  2.003 qw(:Status createSelfTiedObject);
+use IO::Compress::RawDeflate 2.003 ;
+use IO::Compress::Adapter::Deflate 2.003 ;
+use IO::Compress::Adapter::Identity 2.003 ;
+use IO::Compress::Zlib::Extra 2.003 ;
+use IO::Compress::Zip::Constants 2.003 ;
 
 
-use Compress::Raw::Zlib qw(crc32) ;
+use Compress::Raw::Zlib  2.003 qw(crc32) ;
 BEGIN
 {
-    eval { require IO::Compress::Adapter::Bzip2; 
-           import  IO::Compress::Adapter::Bzip2; 
-           require IO::Compress::Bzip2; 
-           import  IO::Compress::Bzip2; 
+    eval { require IO::Compress::Adapter::Bzip2 ; 
+           import  IO::Compress::Adapter::Bzip2 2.003 ; 
+           require IO::Compress::Bzip2 ; 
+           import  IO::Compress::Bzip2 2.003 ; 
          } ;
 }
 
@@ -27,7 +27,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $ZipError);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $ZipError = '';
 
 @ISA = qw(Exporter IO::Compress::RawDeflate);
@@ -438,8 +438,8 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common qw(:Parse);
-    use Compress::Raw::Zlib qw(Z_DEFLATED Z_DEFAULT_COMPRESSION Z_DEFAULT_STRATEGY);
+    use IO::Compress::Base::Common  2.003 qw(:Parse);
+    use Compress::Raw::Zlib  2.003 qw(Z_DEFLATED Z_DEFAULT_COMPRESSION Z_DEFAULT_STRATEGY);
 
     my @Bzip2 = ();
     
@@ -1536,7 +1536,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
