@@ -4,13 +4,13 @@ use warnings;
 use strict;
 use bytes;
 
-use IO::Compress::Base::Common qw(:Status);
+use IO::Compress::Base::Common  2.003 qw(:Status);
 
 our ($VERSION);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 
-use Compress::Raw::Zlib ();
+use Compress::Raw::Zlib  2.003 ();
 
 sub mkUncompObject
 {
