@@ -9,12 +9,12 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate ;
+use IO::Uncompress::RawInflate 2.003 ;
 
-use Compress::Raw::Zlib qw( crc32 ) ;
-use IO::Compress::Base::Common qw(:Status createSelfTiedObject);
-use IO::Compress::Gzip::Constants;
-use IO::Compress::Zlib::Extra;
+use Compress::Raw::Zlib 2.003 qw( crc32 ) ;
+use IO::Compress::Base::Common 2.003 qw(:Status createSelfTiedObject);
+use IO::Compress::Gzip::Constants 2.003 ;
+use IO::Compress::Zlib::Extra 2.003 ;
 
 require Exporter ;
 
@@ -28,7 +28,7 @@ Exporter::export_ok_tags('all');
 
 $GunzipError = '';
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 
 sub new
 {
@@ -47,7 +47,7 @@ sub gunzip
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common qw(:Parse);
+    use IO::Compress::Base::Common  2.003 qw(:Parse);
     return ( 'ParseExtra' => [1, 1, Parse_boolean,  0] ) ;
 }
 
@@ -1174,7 +1174,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
