@@ -5,15 +5,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common qw(:Status createSelfTiedObject);
-use IO::Compress::Zlib::Constants;
+use IO::Compress::Base::Common  2.003 qw(:Status createSelfTiedObject);
+use IO::Compress::Zlib::Constants 2.003 ;
 
-use IO::Uncompress::RawInflate ;
+use IO::Uncompress::RawInflate  2.003 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $InflateError);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $InflateError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::RawInflate );
@@ -1041,7 +1041,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
