@@ -8,13 +8,13 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate ;
-use IO::Compress::Base::Common qw(:Status createSelfTiedObject);
-use IO::Uncompress::Adapter::Identity;
-use IO::Compress::Zlib::Extra;
-use IO::Compress::Zip::Constants;
+use IO::Uncompress::RawInflate  2.003 ;
+use IO::Compress::Base::Common  2.003 qw(:Status createSelfTiedObject);
+use IO::Uncompress::Adapter::Identity 2.003 ;
+use IO::Compress::Zlib::Extra 2.003 ;
+use IO::Compress::Zip::Constants 2.003 ;
 
-use Compress::Raw::Zlib qw(crc32) ;
+use Compress::Raw::Zlib  2.003 qw(crc32) ;
 
 BEGIN
 {
@@ -27,7 +27,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.002';
+$VERSION = '2.003';
 $UnzipError = '';
 
 @ISA    = qw(Exporter IO::Uncompress::RawInflate);
@@ -60,7 +60,7 @@ sub unzip
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common qw(:Parse);
+    use IO::Compress::Base::Common  2.003 qw(:Parse);
 
     
     return (
@@ -1532,7 +1532,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2006 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
